@@ -8,25 +8,16 @@
 #ifndef PA_HTTP_H
 #define PA_HTTP_H
 
-#define IDENT_PA_HTTP_H "$Id: pa_http.h,v 1.8 2012-06-20 20:54:25 moko Exp $"
+#define IDENT_PA_HTTP_H "$Id: pa_http.h,v 1.13 2013/07/23 09:46:58 moko Exp $"
 
 #include "pa_vstring.h"
 #include "pa_vint.h"
 #include "pa_vhash.h"
 #include "pa_vtable.h"
 #include "pa_socks.h"
+#include "pa_request.h"
 
-#ifdef WIN32
-#include <windows.h>
-
-#ifdef CYGWIN
-typedef u_int SOCKET;
-extern "C" int PASCAL FAR closesocket(SOCKET);
-#endif
-
-#else // WIN32
-#define closesocket close
-#endif
+#define HTTP_COOKIES_NAME "cookies"
 
 #ifndef DOXYGEN
 struct File_read_http_result {
@@ -35,6 +26,8 @@ struct File_read_http_result {
 }; 
 #endif
 
+Table* parse_cookies(Request& r, Table *cookies);
+
 char *pa_http_safe_header_name(const char *name);
 
 File_read_http_result pa_internal_file_read_http(Request& r, 
