@@ -8,7 +8,7 @@
 #ifndef PA_REQUEST_H
 #define PA_REQUEST_H
 
-#define IDENT_PA_REQUEST_H "$Id: pa_request.h,v 1.210 2012-03-16 09:24:10 moko Exp $"
+#define IDENT_PA_REQUEST_H "$Id: pa_request.h,v 1.216 2013/10/21 20:49:21 moko Exp $"
 
 #include "pa_pool.h"
 #include "pa_hash.h"
@@ -18,16 +18,10 @@
 #include "pa_request_info.h"
 #include "pa_request_charsets.h"
 #include "pa_sapi.h"
-#include "pa_vconsole.h"
-
-#ifdef RESOURCES_DEBUG
-#include <sys/resource.h>
-#endif
 
 // consts
 
 const uint ANTI_ENDLESS_EXECUTE_RECOURSION=1000;
-const uint ANTI_ENDLESS_JSON_STRING_RECOURSION=100;
 const size_t pseudo_file_no__process=1;
 
 // forwards
@@ -40,13 +34,15 @@ class VForm;
 class VResponse;
 class VCookie;
 class VStateless_class;
+class VConsole;
 
 /// Main workhorse.
 class Request: public PA_Object {
 	friend class Temp_lang;
 	friend class Temp_connection;
-	friend class Request_context_saver;
 	friend class Temp_request_self;
+	friend class Temp_value_element;
+	friend class Request_context_saver;
 	friend class Exception_trace;
 
 public:
@@ -132,8 +128,6 @@ private:
 	*/
 	uint anti_endless_execute_recoursion;
 
-	uint anti_endless_json_string_recoursion;
-
 	///@}
 
 	/// execution stack
@@ -143,6 +137,8 @@ private:
 	Exception_trace exception_trace;
 public:
 
+	bool allow_class_replace;
+
 	//@{ request processing status
 	/// contexts
 	VMethodFrame* method_frame;
@@ -223,21 +219,6 @@ public:
 		anti_endless_execute_recoursion--;
 	}
 
-	uint json_string_recoursion_go_down(){
-		if(++anti_endless_json_string_recoursion==ANTI_ENDLESS_JSON_STRING_RECOURSION){
-			anti_endless_json_string_recoursion=0;
-			throw Exception(PARSER_RUNTIME,
-				0,
-				"call canceled - endless json recursion detected");
-		}
-		return anti_endless_json_string_recoursion;
-	}
-
-	void json_string_recoursion_go_up(){
-		if(anti_endless_json_string_recoursion)
-			anti_endless_json_string_recoursion--;
-	}
-
 	///
 	void use_file_directly(VStateless_class& aclass,
 				const String& file_spec,
@@ -487,7 +468,6 @@ class Request_context_saver {
 	/// execution stack
 	size_t stack;
 	uint anti_endless_execute_recoursion;
-	uint anti_endless_json_string_recoursion;
 	/// contexts
 	VMethodFrame* method_frame;
 	Value* rcontext;
@@ -504,7 +484,6 @@ public:
 		exception_trace_bottom(ar.exception_trace.bottom_index()),	
 		stack(ar.stack.top_index()),
 		anti_endless_execute_recoursion(ar.anti_endless_execute_recoursion),
-		anti_endless_json_string_recoursion(ar.anti_endless_json_string_recoursion),
 		method_frame(ar.method_frame),
 		rcontext(ar.rcontext),
 		wcontext(ar.wcontext),
@@ -515,7 +494,6 @@ public:
 		fr.exception_trace.set_bottom_index(exception_trace_bottom);
 		fr.stack.set_top_index(stack);
 		fr.anti_endless_execute_recoursion=anti_endless_execute_recoursion;
-		fr.anti_endless_json_string_recoursion=anti_endless_json_string_recoursion;
 		fr.method_frame=method_frame, fr.rcontext=rcontext; fr.wcontext=wcontext;
 		fr.flang=flang;
 		fr.fconnection=fconnection;
@@ -562,6 +540,29 @@ public:
 	}
 };
 
+///	Auto-object used for temporary changing Request::allow_class_replace.
+class Temp_class_replace {
+	Request& frequest;
+public:
+	Temp_class_replace(Request& arequest, bool avalue) : frequest(arequest){
+		frequest.allow_class_replace=avalue;
+	}
+	~Temp_class_replace() {
+		frequest.allow_class_replace=false;
+	}
+};
+
+///	Auto-object used for temporarily substituting/removing elements
+class Temp_value_element {
+	Request& frequest;
+	Value& fwhere;
+	const String& fname;
+	Value* saved;
+public:
+	Temp_value_element(Request& arequest, Value& awhere, const String& aname, Value* awhat);
+	~Temp_value_element();
+};
+
 // defines for externs
 
 #define EXCEPTION_HANDLED_PART_NAME "handled"
