@@ -107,13 +107,9 @@
  * ----------------------------------------------------------------------------
  */
 
-#include <string.h>
-
 #include "pa_md5.h"
 
-volatile const char * IDENT_PA_MD5_C="$Id: pa_md5c.c,v 1.14 2012-03-16 09:24:11 moko Exp $" IDENT_PA_MD5_H;
-
-#define pa_pa_cpystrn(strDest, strSource, count) strncpy(strDest, strSource, count)
+volatile const char * IDENT_PA_MD5_C="$Id: pa_md5c.c,v 1.17 2013/07/21 14:04:41 moko Exp $" IDENT_PA_MD5_H;
 
 /* Constants for MD5Transform routine.
  */
@@ -185,7 +181,7 @@ static unsigned char PADDING[64] =
 
 /* MD5 initialization. Begins an MD5 operation, writing a new context.
  */
-PA_API_EXPORT(void) pa_MD5Init(PA_MD5_CTX *context)
+void pa_MD5Init(PA_MD5_CTX *context)
 {
     context->count[0] = context->count[1] = 0;
     /* Load magic initialization constants. */
@@ -199,7 +195,7 @@ PA_API_EXPORT(void) pa_MD5Init(PA_MD5_CTX *context)
    operation, processing another message block, and updating the
    context.
  */
-PA_API_EXPORT(void) pa_MD5Update(PA_MD5_CTX *context, const unsigned char *input,
+void pa_MD5Update(PA_MD5_CTX *context, const unsigned char *input,
 			      unsigned int inputLen)
 {
     unsigned int i, idx, partLen;
@@ -259,7 +255,7 @@ PA_API_EXPORT(void) pa_MD5Update(PA_MD5_CTX *context, const unsigned char *input
 /* MD5 finalization. Ends an MD5 message-digest operation, writing the
    the message digest and zeroizing the context.
  */
-PA_API_EXPORT(void) pa_MD5Final(unsigned char digest[16], PA_MD5_CTX *context)
+void pa_MD5Final(unsigned char digest[16], PA_MD5_CTX *context)
 {
     unsigned char bits[8];
     unsigned int idx, padLen;
@@ -420,7 +416,7 @@ static void Decode(UINT4 *output, const unsigned char *input, unsigned int len)
  * the FreeBSD 3.0 /usr/src/lib/libcrypt/crypt.c file, which is
  * licenced as stated at the top of this file.
  */
-PA_API_EXPORT(void) pa_to64(char *s, unsigned long v, int n)
+void pa_to64(char *s, unsigned long v, int n)
 {
     static unsigned char itoa64[] =         /* 0 ... 63 => ASCII - 64 */
 	"./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
@@ -431,7 +427,7 @@ PA_API_EXPORT(void) pa_to64(char *s, unsigned long v, int n)
     }
 }
 
-PA_API_EXPORT(void) pa_MD5Encode(const unsigned char *pw,
+void pa_MD5Encode(const unsigned char *pw,
 			      const unsigned char *salt,
 			      char *result, size_t nbytes)
 {
@@ -531,8 +527,8 @@ PA_API_EXPORT(void) pa_MD5Encode(const unsigned char *pw,
      * Now make the output string.  We know our limitations, so we
      * can use the string routines without bounds checking.
      */
-    pa_pa_cpystrn(passwd, PA_MD5PW_ID, PA_MD5PW_IDLEN + 1);
-    pa_pa_cpystrn(passwd + PA_MD5PW_IDLEN, (char *)sp, sl + 1);
+    strncpy(passwd, PA_MD5PW_ID, PA_MD5PW_IDLEN + 1);
+    strncpy(passwd + PA_MD5PW_IDLEN, (char *)sp, sl + 1);
     passwd[PA_MD5PW_IDLEN + sl]     = '$';
     passwd[PA_MD5PW_IDLEN + sl + 1] = '\0';
 
@@ -583,5 +579,5 @@ PA_API_EXPORT(void) pa_MD5Encode(const unsigned char *pw,
      */
     memset(final, 0, sizeof(final));
 
-    pa_pa_cpystrn(result, passwd, nbytes - 1);
+    strncpy(result, passwd, nbytes - 1);
 }
