@@ -8,7 +8,7 @@
 #ifndef PA_VALUE_H
 #define PA_VALUE_H
 
-#define IDENT_PA_VALUE_H "$Id: pa_value.h,v 1.149 2012-05-28 19:47:52 moko Exp $"
+#define IDENT_PA_VALUE_H "$Id: pa_value.h,v 1.152 2013/10/08 21:25:46 moko Exp $"
 
 #include "pa_common.h"
 #include "pa_array.h"
@@ -40,6 +40,7 @@ struct Json_options {
 	Value* default_method;
 	Value* params;
 	bool skip_unknown;
+	uint json_string_recoursion;
 	const char* indent;
 	XDocOutputOptions* xdoc_options;
 	enum Date { D_SQL, D_GMT, D_TIMESTAMP } date;
@@ -53,6 +54,7 @@ struct Json_options {
 		params(NULL),
 		skip_unknown(false),
 		xdoc_options(NULL),
+		json_string_recoursion(0),
 		indent(NULL),
 		date(D_SQL),
 		table(T_OBJECT),
@@ -162,7 +164,7 @@ public: // Value
 	/// store Value element under @a name
 	/// @returns putter method junction, or it can just report[PUT_ELEMENT_REPLACED_ELEMENT] 
 	/// that it replaced something in base fields 
-	virtual const VJunction* put_element(const String& aname, Value* /*avalue*/, bool /*areplace*/) { 
+	virtual const VJunction* put_element(const String& aname, Value* /*avalue*/) { 
 		// to prevent modification of system classes,
 		// created at system startup, and not having exception
 		// handler installed, we neet to bark using request.pool
@@ -176,6 +178,7 @@ public: // Value
 	virtual void disable_default_getter(){ }
 	virtual void disable_default_setter(){ }
 	virtual bool is_enabled_default_getter(){ return true; }
+	virtual bool is_enabled_default_setter(){ return true; }
 	
 	/// extract VStateless_class
 	virtual VStateless_class* get_class()=0;
