@@ -8,13 +8,12 @@
 #ifndef PA_VCLASS_H
 #define PA_VCLASS_H
 
-#define IDENT_PA_VCLASS_H "$Id: pa_vclass.h,v 1.60 2012-06-08 02:04:11 misha Exp $"
+#define IDENT_PA_VCLASS_H "$Id: pa_vclass.h,v 1.62 2013/10/08 21:25:46 moko Exp $"
 
 // includes
 
 #include "pa_vstateless_class.h"
 #include "pa_vjunction.h"
-#include "pa_vobject.h"
 
 /**	stores 
 - static fields, getters & setters: VClass::ffields
@@ -29,7 +28,10 @@ public: // Value
 	override Value* as(const char* atype);
 
 	override Value* get_element(Value& aself, const String& aname);
-	override const VJunction* put_element(Value& self, const String& name, Value* value, bool replace);
+	override const VJunction* put_element(Value& self, const String& name, Value* value);
+	// for VObject::put_element
+	const VJunction* put_element_replace_only(Value& self, const String& name, Value* value);
+
 	override Value* create_new_value(Pool&);
 
 	override HashStringValue *get_hash();
@@ -42,13 +44,30 @@ public:
 	override HashStringProperty* get_properties(){ return &ffields; };
 	override void set_base(VStateless_class* abase);
 
+	/// VClass default getter & setter support
+	override void enable_default_getter(){ state |= IS_GETTER_ACTIVE; }
+	override void enable_default_setter(){ if(has_default_setter()) state |= IS_SETTER_ACTIVE; }
+	override void disable_default_getter(){ state &= ~IS_GETTER_ACTIVE; }
+	override void disable_default_setter(){ state &= ~IS_SETTER_ACTIVE; }
+	override bool is_enabled_default_getter(){ return (state & IS_GETTER_ACTIVE) > 0; }
+	override bool is_enabled_default_setter(){ return (state & IS_SETTER_ACTIVE) > 0; }
+
 private:
 
+	enum State {
+		IS_GETTER_ACTIVE = 0x01,
+		IS_SETTER_ACTIVE = 0x02
+	};
+
+	int state; // default setter & getter state
+
+	HashStringProperty ffields;
+
 	Property& get_property(const String& aname);
 
-private: // self
+public:
 
-	HashStringProperty ffields;
+	VClass() : state(IS_GETTER_ACTIVE){}
 
 };
 
