@@ -8,7 +8,7 @@
 #ifndef PA_VHASHFILE_H
 #define PA_VHASHFILE_H
 
-#define IDENT_PA_VHASHFILE_H "$Id: pa_vhashfile.h,v 1.41 2012-06-08 02:02:31 misha Exp $"
+#define IDENT_PA_VHASHFILE_H "$Id: pa_vhashfile.h,v 1.43 2013/10/04 21:21:56 moko Exp $"
 
 #include "classes.h"
 #include "pa_pool.h"
@@ -49,9 +49,9 @@ public: // value
 	}
 	
 	/// VHashfile: (key)=value, (key)=(value+expires)
-	override const VJunction* put_element(const String& aname, Value* avalue, bool /*replace*/) { 
+	override const VJunction* put_element(const String& aname, Value* avalue) {
 		put_field(aname, avalue);
-		return false; // nobody is supposed to derive from hashfile, so does not matter
+		return 0; // nobody is supposed to derive from hashfile, so does not matter
 	}
 
 public: // usage
