@@ -8,7 +8,7 @@
 #ifndef PA_VOBJECT_H
 #define PA_VOBJECT_H
 
-#define IDENT_PA_VOBJECT_H "$Id: pa_vobject.h,v 1.59 2012-05-28 19:47:52 moko Exp $"
+#define IDENT_PA_VOBJECT_H "$Id: pa_vobject.h,v 1.62 2013/10/08 21:25:46 moko Exp $"
 
 // includes
 
@@ -27,7 +27,7 @@
 */
 class VObject: public Value {
 
-	VStateless_class& fclass;
+	VClass& fclass;
 	HashStringValue ffields;
 
 	enum State {
@@ -57,7 +57,7 @@ public: // Value
 	override HashStringValue* get_fields() { return &ffields; }
 
 	override Value* get_element(const String& aname);
-	override const VJunction* put_element(const String& name, Value* value, bool replace);
+	override const VJunction* put_element(const String& name, Value* value);
 
 	override const String* get_json_string(Json_options& options);
 
@@ -67,15 +67,15 @@ public: // Value
 	override void disable_default_getter(){ state &= ~IS_GETTER_ACTIVE; }
 	override void disable_default_setter(){ state &= ~IS_SETTER_ACTIVE; }
 	override bool is_enabled_default_getter(){ return (state & IS_GETTER_ACTIVE) > 0; }
-			 bool is_enabled_default_setter(){ return (state & IS_SETTER_ACTIVE) > 0; }
+	override bool is_enabled_default_setter(){ return (state & IS_SETTER_ACTIVE) > 0; }
 
 public: // creation
 
-	VObject(VStateless_class& aclass): fclass(aclass), state(IS_GETTER_ACTIVE){}
+	VObject(VClass& aclass): fclass(aclass), state(IS_GETTER_ACTIVE){}
 
 private:
 
-	Value* get_scalar_value(char* as_something) const;
+	Value* get_scalar_value(const char* as_something) const;
 };
 
 ///	Auto-objects used for temporarily disabling setter/getter
