@@ -8,7 +8,7 @@
 #ifndef PA_VREQUEST_H
 #define PA_VREQUEST_H
 
-#define IDENT_PA_VREQUEST_H "$Id: pa_vrequest.h,v 1.39 2012-03-16 09:24:19 moko Exp $"
+#define IDENT_PA_VREQUEST_H "$Id: pa_vrequest.h,v 1.40 2013/10/04 21:21:57 moko Exp $"
 
 // includes
 
@@ -47,7 +47,7 @@ public: // Value
 	override Value* get_element(const String& name);
 
 	/// request: (key)=value
-	override const VJunction* put_element(const String& name, Value* value, bool replace);
+	override const VJunction* put_element(const String& name, Value* value);
 
 public: // usage
 
